slepc-3.18.0 2022-10-01
Report Typos and Errors

# SVDViewFromOptions

View from options

### Synopsis

    #include "slepcsvd.h"
    PetscErrorCode SVDViewFromOptions(SVD svd,PetscObject obj,const char name[])

Collective on SVD

### Input Parameters

| svd | - the singular value solver context
| obj | - optional object
| name | - command line option

### See Also

SVDView(), SVDCreate()

### Level

intermediate

### Location

src/svd/interface/svdview.c
Index of all SVD routines
Table of Contents for all manual pages
Index of all manual pages